@@ -1,12 +1,9 @@
 from nose.plugins.skip import SkipTest
-from helpers import run_bch, get_config_path, run_batch, set_test_fpath_root
-import os
-from blazeutils.testing import logging_handler
-
+from .helpers import run_bch
 
 def test_no_commands_found_error():
     result = run_bch(use_test_config='none', expect_error=True)
-    assert 'Error: no command plugins registered' in result.stderr, str(result)
+    assert 'Error: no commands found or registered' in result.stderr, str(result)
 
 def test_no_commands_given_is_error():
     result = run_bch(expect_error=True)
@@ -31,10 +28,3 @@ def test_system_command():
 def test_user_command():
     result = run_bch('hwu')
     assert 'hello world from user command' in result.stdout, str(result)
-
-def test_plugin_command():
-    result = run_bch('hello-world', load_test_plugins = True)
-    assert 'hello world' in result.stdout, str(result)
-
-    result = run_bch('hello-world', '--name', 'foo', load_test_plugins = True)
-    assert 'hello foo' in result.stdout, str(result)
